@@ -1,12 +1,10 @@
 #!/usr/bin/python
-# This file is part of Ansible
+# -*- coding: utf-8 -*-
+
+# Copyright: Contributors to the Ansible project
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
-from __future__ import (absolute_import, division, print_function)
-__metaclass__ = type
-
-
-DOCUMENTATION = r'''
+DOCUMENTATION = r"""
 ---
 module: ecs_taskdefinition
 version_added: 1.0.0
@@ -466,6 +464,49 @@ options:
                 description: The health check command and associated configuration parameters for the container.
                 required: False
                 type: dict
+                suboptions:
+                    command:
+                        description:
+                            - A string array representing the command that the container runs to determine if it is healthy.
+                            - >
+                              The string array must start with CMD to run the command arguments directly,
+                              or CMD-SHELL to run the command with the container's default shell.
+                            - An exit code of 0 indicates success, and non-zero exit code indicates failure.
+                        required: False
+                        type: list
+                        elements: str
+                    interval:
+                        description:
+                            - The time period in seconds between each health check execution.
+                            - You may specify between 5 and 300 seconds. The default value is 30 seconds.
+                        required: False
+                        type: int
+                        default: 30
+                    retries:
+                        description:
+                            - The number of times to retry a failed health check before the container is considered unhealthy.
+                            - You may specify between 1 and 10 retries. The default value is 3.
+                        required: False
+                        type: int
+                        default: 3
+                    startPeriod:
+                        description:
+                            - >
+                              The optional grace period to provide containers time to bootstrap
+                              before failed health checks count towards the maximum number of retries.
+                            - You can specify between 0 and 300 seconds. By default, the startPeriod is disabled.
+                            - >
+                              Note: If a health check succeeds within the startPeriod,
+                              then the container is considered healthy and any subsequent failures count toward the maximum number of retries.
+                        required: False
+                        type: int
+                    timeout:
+                        description:
+                            - The time period in seconds to wait for a health check to succeed before it is considered a failure.
+                            - You may specify between 2 and 60 seconds. The default value is 5.
+                        required: False
+                        type: int
+                        default: 5
             systemControls:
                 description: A list of namespaced kernel parameters to set in the container.
                 required: False
@@ -493,6 +534,32 @@ options:
                         description: The type of resource to assign to a container.
                         type: str
                         choices: ['GPU', 'InferenceAccelerator']
+            firelensConfiguration:
+                description:
+                    - The FireLens configuration for the container.
+                    - This is used to specify and configure a log router for container logs.
+                required: False
+                type: dict
+                suboptions:
+                    type:
+                        description:
+                            - The log router to use. The valid values are C(fluentd) or C(fluentbit).
+                        required: False
+                        type: str
+                        choices:
+                            - fluentd
+                            - fluentbit
+                    options:
+                        description:
+                            - The options to use when configuring the log router.
+                            - This field is optional and can be used to specify a custom configuration
+                              file or to add additional metadata, such as the task, task definition, cluster,
+                              and container instance details to the log event.
+                            - If specified, the syntax to use is
+                              C({"enable-ecs-log-metadata":"true|false","config-file-type:"s3|file","config-file-value":"arn:aws:s3:::mybucket/fluent.conf|filepath"}).
+                            - For more information, see U(https://docs.aws.amazon.com/AmazonECS/latest/developerguide/using_firelens.html#firelens-taskdef).
+                        required: False
+                        type: dict
     network_mode:
         description:
             - The Docker networking mode to use for the containers in the task.
@@ -508,11 +575,13 @@ options:
               the permissions that are specified in this role.
         required: false
         type: str
+        default: ''
     execution_role_arn:
         description:
             - The Amazon Resource Name (ARN) of the task execution role that the Amazon ECS container agent and the Docker daemon can assume.
         required: false
         type: str
+        default: ''
     volumes:
         description:
             - A list of names of volumes to be attached.
@@ -558,12 +627,34 @@ options:
             expression:
                 description: A cluster query language expression to apply to the constraint.
                 type: str
+    runtime_platform:
+        version_added: 6.4.0
+        description:
+            - runtime platform configuration for the task
+        required: false
+        type: dict
+        default: {
+                    "operatingSystemFamily": "LINUX",
+                    "cpuArchitecture": "X86_64"
+                }
+        suboptions:
+            cpuArchitecture:
+                description: The CPU Architecture type to be used by the task
+                type: str
+                required: false
+                choices: ['X86_64', 'ARM64']
+            operatingSystemFamily:
+                description: OS type to be used by the task
+                type: str
+                required: false
+                choices: ['LINUX', 'WINDOWS_SERVER_2019_FULL', 'WINDOWS_SERVER_2019_CORE', 'WINDOWS_SERVER_2022_FULL', 'WINDOWS_SERVER_2022_CORE']
 extends_documentation_fragment:
-- amazon.aws.aws
-- amazon.aws.ec2
-'''
+    - amazon.aws.common.modules
+    - amazon.aws.region.modules
+    - amazon.aws.boto3
+"""
 
-EXAMPLES = r'''
+EXAMPLES = r"""
 - name: Create task definition
   community.aws.ecs_taskdefinition:
     containers:
@@ -674,22 +765,46 @@ EXAMPLES = r'''
     memory: 1GB
     state: present
     network_mode: awsvpc
-'''
-RETURN = r'''
+
+# Create Task Definition with health check
+- name: Create task definition
+  community.aws.ecs_taskdefinition:
+    family: nginx
+    containers:
+    - name: nginx
+      essential: true
+      image: "nginx"
+      portMappings:
+      - containerPort: 8080
+        hostPort: 8080
+      cpu: 512
+      memory: 1024
+      healthCheck:
+        command:
+            - CMD-SHELL
+            - /app/healthcheck.py
+        interval: 60
+        retries: 3
+        startPeriod: 15
+        timeout: 15
+    state: present
+"""
+
+RETURN = r"""
 taskdefinition:
     description: a reflection of the input parameters
     type: dict
     returned: always
-'''
+"""
 
 try:
     import botocore
 except ImportError:
     pass  # caught by AnsibleAWSModule
 
+from ansible_collections.amazon.aws.plugins.module_utils.retries import AWSRetry
 
-from ansible_collections.amazon.aws.plugins.module_utils.core import AnsibleAWSModule
-from ansible_collections.amazon.aws.plugins.module_utils.ec2 import AWSRetry
+from ansible_collections.community.aws.plugins.module_utils.modules import AnsibleCommunityAWSModule as AnsibleAWSModule
 
 
 class EcsTaskManager:
@@ -698,49 +813,65 @@ class EcsTaskManager:
     def __init__(self, module):
         self.module = module
 
-        self.ecs = module.client('ecs', AWSRetry.jittered_backoff())
+        self.ecs = module.client("ecs", AWSRetry.jittered_backoff())
 
     def describe_task(self, task_name):
         try:
             response = self.ecs.describe_task_definition(aws_retry=True, taskDefinition=task_name)
-            return response['taskDefinition']
+            return response["taskDefinition"]
         except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:
             return None
 
-    def register_task(self, family, task_role_arn, execution_role_arn, network_mode, container_definitions,
-                      volumes, launch_type, cpu, memory, placement_constraints):
+    def register_task(
+        self,
+        family,
+        task_role_arn,
+        execution_role_arn,
+        network_mode,
+        container_definitions,
+        volumes,
+        launch_type,
+        cpu,
+        memory,
+        placement_constraints,
+        runtime_platform,
+    ):
         validated_containers = []
 
-        # Ensures the number parameters are int as required by boto
+        # Ensures the number parameters are int as required by the AWS SDK
         for container in container_definitions:
-            for param in ('memory', 'cpu', 'memoryReservation', 'startTimeout', 'stopTimeout'):
+            for param in ("memory", "cpu", "memoryReservation", "startTimeout", "stopTimeout"):
                 if param in container:
                     container[param] = int(container[param])
 
-            if 'portMappings' in container:
-                for port_mapping in container['portMappings']:
-                    for port in ('hostPort', 'containerPort'):
+            if "portMappings" in container:
+                for port_mapping in container["portMappings"]:
+                    for port in ("hostPort", "containerPort"):
                         if port in port_mapping:
                             port_mapping[port] = int(port_mapping[port])
-                    if network_mode == 'awsvpc' and 'hostPort' in port_mapping:
-                        if port_mapping['hostPort'] != port_mapping.get('containerPort'):
-                            self.module.fail_json(msg="In awsvpc network mode, host port must be set to the same as "
-                                                  "container port or not be set")
+                    if network_mode == "awsvpc" and "hostPort" in port_mapping:
+                        if port_mapping["hostPort"] != port_mapping.get("containerPort"):
+                            self.module.fail_json(
+                                msg=(
+                                    "In awsvpc network mode, host port must be set to the same as "
+                                    "container port or not be set"
+                                )
+                            )
 
-            if 'linuxParameters' in container:
-                for linux_param in container.get('linuxParameters'):
-                    if linux_param == 'tmpfs':
-                        for tmpfs_param in container['linuxParameters']['tmpfs']:
-                            if 'size' in tmpfs_param:
-                                tmpfs_param['size'] = int(tmpfs_param['size'])
+            if "linuxParameters" in container:
+                for linux_param in container.get("linuxParameters"):
+                    if linux_param == "tmpfs":
+                        for tmpfs_param in container["linuxParameters"]["tmpfs"]:
+                            if "size" in tmpfs_param:
+                                tmpfs_param["size"] = int(tmpfs_param["size"])
 
-                    for param in ('maxSwap', 'swappiness', 'sharedMemorySize'):
+                    for param in ("maxSwap", "swappiness", "sharedMemorySize"):
                         if param in linux_param:
-                            container['linuxParameters'][param] = int(container['linuxParameters'][param])
+                            container["linuxParameters"][param] = int(container["linuxParameters"][param])
 
-            if 'ulimits' in container:
-                for limits_mapping in container['ulimits']:
-                    for limit in ('softLimit', 'hardLimit'):
+            if "ulimits" in container:
+                for limits_mapping in container["ulimits"]:
+                    for limit in ("softLimit", "hardLimit"):
                         if limit in limits_mapping:
                             limits_mapping[limit] = int(limits_mapping[limit])
 
@@ -750,47 +881,44 @@ class EcsTaskManager:
             family=family,
             taskRoleArn=task_role_arn,
             containerDefinitions=container_definitions,
-            volumes=volumes
+            volumes=volumes,
         )
-        if network_mode != 'default':
-            params['networkMode'] = network_mode
+        if network_mode != "default":
+            params["networkMode"] = network_mode
         if cpu:
-            params['cpu'] = cpu
+            params["cpu"] = cpu
         if memory:
-            params['memory'] = memory
+            params["memory"] = memory
         if launch_type:
-            params['requiresCompatibilities'] = [launch_type]
+            params["requiresCompatibilities"] = [launch_type]
         if execution_role_arn:
-            params['executionRoleArn'] = execution_role_arn
+            params["executionRoleArn"] = execution_role_arn
         if placement_constraints:
-            params['placementConstraints'] = placement_constraints
+            params["placementConstraints"] = placement_constraints
+        if runtime_platform:
+            params["runtimePlatform"] = runtime_platform
 
         try:
             response = self.ecs.register_task_definition(aws_retry=True, **params)
         except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:
             self.module.fail_json_aws(e, msg="Failed to register task")
 
-        return response['taskDefinition']
+        return response["taskDefinition"]
 
     def describe_task_definitions(self, family):
-        data = {
-            "taskDefinitionArns": [],
-            "nextToken": None
-        }
+        data = {"taskDefinitionArns": [], "nextToken": None}
 
         def fetch():
             # Boto3 is weird about params passed, so only pass nextToken if we have a value
-            params = {
-                'familyPrefix': family
-            }
+            params = {"familyPrefix": family}
 
-            if data['nextToken']:
-                params['nextToken'] = data['nextToken']
+            if data["nextToken"]:
+                params["nextToken"] = data["nextToken"]
 
             result = self.ecs.list_task_definitions(**params)
-            data['taskDefinitionArns'] += result['taskDefinitionArns']
-            data['nextToken'] = result.get('nextToken', None)
-            return data['nextToken'] is not None
+            data["taskDefinitionArns"] += result["taskDefinitionArns"]
+            data["nextToken"] = result.get("nextToken", None)
+            return data["nextToken"] is not None
 
         # Fetch all the arns, possibly across multiple pages
         while fetch():
@@ -799,118 +927,154 @@ class EcsTaskManager:
         # Return the full descriptions of the task definitions, sorted ascending by revision
         return list(
             sorted(
-                [self.ecs.describe_task_definition(taskDefinition=arn)['taskDefinition'] for arn in data['taskDefinitionArns']],
-                key=lambda td: td['revision']
+                [
+                    self.ecs.describe_task_definition(taskDefinition=arn)["taskDefinition"]
+                    for arn in data["taskDefinitionArns"]
+                ],
+                key=lambda td: td["revision"],
             )
         )
 
     def deregister_task(self, taskArn):
         response = self.ecs.deregister_task_definition(taskDefinition=taskArn)
-        return response['taskDefinition']
+        return response["taskDefinition"]
 
 
 def main():
     argument_spec = dict(
-        state=dict(required=True, choices=['present', 'absent']),
-        arn=dict(required=False, type='str'),
-        family=dict(required=False, type='str'),
-        revision=dict(required=False, type='int'),
-        force_create=dict(required=False, default=False, type='bool'),
-        containers=dict(required=True, type='list', elements='dict'),
-        network_mode=dict(required=False, default='bridge', choices=['default', 'bridge', 'host', 'none', 'awsvpc'], type='str'),
-        task_role_arn=dict(required=False, default='', type='str'),
-        execution_role_arn=dict(required=False, default='', type='str'),
-        volumes=dict(required=False, type='list', elements='dict'),
-        launch_type=dict(required=False, choices=['EC2', 'FARGATE']),
+        state=dict(required=True, choices=["present", "absent"]),
+        arn=dict(required=False, type="str"),
+        family=dict(required=False, type="str"),
+        revision=dict(required=False, type="int"),
+        force_create=dict(required=False, default=False, type="bool"),
+        containers=dict(required=True, type="list", elements="dict"),
+        network_mode=dict(
+            required=False, default="bridge", choices=["default", "bridge", "host", "none", "awsvpc"], type="str"
+        ),
+        task_role_arn=dict(required=False, default="", type="str"),
+        execution_role_arn=dict(required=False, default="", type="str"),
+        volumes=dict(required=False, type="list", elements="dict"),
+        launch_type=dict(required=False, choices=["EC2", "FARGATE"]),
         cpu=dict(),
-        memory=dict(required=False, type='str'),
-        placement_constraints=dict(required=False, type='list', elements='dict',
-                                   options=dict(type=dict(type='str'), expression=dict(type='str'))),
+        memory=dict(required=False, type="str"),
+        placement_constraints=dict(
+            required=False,
+            type="list",
+            elements="dict",
+            options=dict(type=dict(type="str"), expression=dict(type="str")),
+        ),
+        runtime_platform=dict(
+            required=False,
+            default={"operatingSystemFamily": "LINUX", "cpuArchitecture": "X86_64"},
+            type="dict",
+            options=dict(
+                cpuArchitecture=dict(required=False, choices=["X86_64", "ARM64"]),
+                operatingSystemFamily=dict(
+                    required=False,
+                    choices=[
+                        "LINUX",
+                        "WINDOWS_SERVER_2019_FULL",
+                        "WINDOWS_SERVER_2019_CORE",
+                        "WINDOWS_SERVER_2022_FULL",
+                        "WINDOWS_SERVER_2022_CORE",
+                    ],
+                ),
+            ),
+        ),
     )
 
-    module = AnsibleAWSModule(argument_spec=argument_spec,
-                              supports_check_mode=True,
-                              required_if=[('launch_type', 'FARGATE', ['cpu', 'memory'])]
-                              )
+    module = AnsibleAWSModule(
+        argument_spec=argument_spec,
+        supports_check_mode=True,
+        required_if=[("launch_type", "FARGATE", ["cpu", "memory"])],
+    )
 
     task_to_describe = None
     task_mgr = EcsTaskManager(module)
     results = dict(changed=False)
 
-    if module.params['state'] == 'present':
-        if 'containers' not in module.params or not module.params['containers']:
+    if module.params["state"] == "present":
+        if "containers" not in module.params or not module.params["containers"]:
             module.fail_json(msg="To use task definitions, a list of containers must be specified")
 
-        if 'family' not in module.params or not module.params['family']:
+        if "family" not in module.params or not module.params["family"]:
             module.fail_json(msg="To use task definitions, a family must be specified")
 
-        network_mode = module.params['network_mode']
-        launch_type = module.params['launch_type']
-        placement_constraints = module.params['placement_constraints']
-        if launch_type == 'FARGATE':
-            if network_mode != 'awsvpc':
+        network_mode = module.params["network_mode"]
+        launch_type = module.params["launch_type"]
+        placement_constraints = module.params["placement_constraints"]
+        if launch_type == "FARGATE":
+            if network_mode != "awsvpc":
                 module.fail_json(msg="To use FARGATE launch type, network_mode must be awsvpc")
             if placement_constraints:
                 module.fail_json(msg="Task placement constraints are not supported for tasks run on Fargate")
 
-        for container in module.params['containers']:
-            if container.get('links') and network_mode == 'awsvpc':
-                module.fail_json(msg='links parameter is not supported if network mode is awsvpc.')
+        for container in module.params["containers"]:
+            if container.get("links") and network_mode == "awsvpc":
+                module.fail_json(msg="links parameter is not supported if network mode is awsvpc.")
 
-            for environment in container.get('environment', []):
-                environment['value'] = environment['value']
+            for environment in container.get("environment", []):
+                environment["value"] = environment["value"]
 
-            for environment_file in container.get('environmentFiles', []):
-                if environment_file['type'] != 's3':
-                    module.fail_json(msg='The only supported value for environmentFiles is s3.')
+            for environment_file in container.get("environmentFiles", []):
+                if environment_file["type"] != "s3":
+                    module.fail_json(msg="The only supported value for environmentFiles is s3.")
 
-            for linux_param in container.get('linuxParameters', {}):
-                if linux_param == 'maxSwap' and launch_type == 'FARGATE':
-                    module.fail_json(msg='devices parameter is not supported with the FARGATE launch type.')
+            for linux_param in container.get("linuxParameters", {}):
+                if linux_param == "maxSwap" and launch_type == "FARGATE":
+                    module.fail_json(msg="devices parameter is not supported with the FARGATE launch type.")
 
-                if linux_param == 'maxSwap' and launch_type == 'FARGATE':
-                    module.fail_json(msg='maxSwap parameter is not supported with the FARGATE launch type.')
-                elif linux_param == 'maxSwap' and int(container['linuxParameters']['maxSwap']) < 0:
-                    module.fail_json(msg='Accepted values for maxSwap are 0 or any positive integer.')
+                if linux_param == "maxSwap" and launch_type == "FARGATE":
+                    module.fail_json(msg="maxSwap parameter is not supported with the FARGATE launch type.")
+                elif linux_param == "maxSwap" and int(container["linuxParameters"]["maxSwap"]) < 0:
+                    module.fail_json(msg="Accepted values for maxSwap are 0 or any positive integer.")
 
-                if (
-                    linux_param == 'swappiness' and
-                    (int(container['linuxParameters']['swappiness']) < 0 or int(container['linuxParameters']['swappiness']) > 100)
+                if linux_param == "swappiness" and (
+                    int(container["linuxParameters"]["swappiness"]) < 0
+                    or int(container["linuxParameters"]["swappiness"]) > 100
                 ):
-                    module.fail_json(msg='Accepted values for swappiness are whole numbers between 0 and 100.')
+                    module.fail_json(msg="Accepted values for swappiness are whole numbers between 0 and 100.")
 
-                if linux_param == 'sharedMemorySize' and launch_type == 'FARGATE':
-                    module.fail_json(msg='sharedMemorySize parameter is not supported with the FARGATE launch type.')
+                if linux_param == "sharedMemorySize" and launch_type == "FARGATE":
+                    module.fail_json(msg="sharedMemorySize parameter is not supported with the FARGATE launch type.")
 
-                if linux_param == 'tmpfs' and launch_type == 'FARGATE':
-                    module.fail_json(msg='tmpfs parameter is not supported with the FARGATE launch type.')
+                if linux_param == "tmpfs" and launch_type == "FARGATE":
+                    module.fail_json(msg="tmpfs parameter is not supported with the FARGATE launch type.")
 
-            if container.get('hostname') and network_mode == 'awsvpc':
-                module.fail_json(msg='hostname parameter is not supported when the awsvpc network mode is used.')
+            if container.get("hostname") and network_mode == "awsvpc":
+                module.fail_json(msg="hostname parameter is not supported when the awsvpc network mode is used.")
 
-            if container.get('extraHosts') and network_mode == 'awsvpc':
-                module.fail_json(msg='extraHosts parameter is not supported when the awsvpc network mode is used.')
+            if container.get("extraHosts") and network_mode == "awsvpc":
+                module.fail_json(msg="extraHosts parameter is not supported when the awsvpc network mode is used.")
 
-        family = module.params['family']
-        existing_definitions_in_family = task_mgr.describe_task_definitions(module.params['family'])
+        family = module.params["family"]
+        existing_definitions_in_family = task_mgr.describe_task_definitions(module.params["family"])
 
-        if 'revision' in module.params and module.params['revision']:
+        if "revision" in module.params and module.params["revision"]:
             # The definition specifies revision. We must guarantee that an active revision of that number will result from this.
-            revision = int(module.params['revision'])
+            revision = int(module.params["revision"])
 
             # A revision has been explicitly specified. Attempt to locate a matching revision
-            tasks_defs_for_revision = [td for td in existing_definitions_in_family if td['revision'] == revision]
+            tasks_defs_for_revision = [td for td in existing_definitions_in_family if td["revision"] == revision]
             existing = tasks_defs_for_revision[0] if len(tasks_defs_for_revision) > 0 else None
 
-            if existing and existing['status'] != "ACTIVE":
+            if existing and existing["status"] != "ACTIVE":
                 # We cannot reactivate an inactive revision
-                module.fail_json(msg="A task in family '%s' already exists for revision %d, but it is inactive" % (family, revision))
+                module.fail_json(
+                    msg=f"A task in family '{family}' already exists for revision {int(revision)}, but it is inactive"
+                )
             elif not existing:
                 if not existing_definitions_in_family and revision != 1:
-                    module.fail_json(msg="You have specified a revision of %d but a created revision would be 1" % revision)
-                elif existing_definitions_in_family and existing_definitions_in_family[-1]['revision'] + 1 != revision:
-                    module.fail_json(msg="You have specified a revision of %d but a created revision would be %d" %
-                                         (revision, existing_definitions_in_family[-1]['revision'] + 1))
+                    module.fail_json(
+                        msg=f"You have specified a revision of {int(revision)} but a created revision would be 1"
+                    )
+                elif existing_definitions_in_family and existing_definitions_in_family[-1]["revision"] + 1 != revision:
+                    module.fail_json(
+                        msg=(
+                            f"You have specified a revision of {int(revision)} but a created revision would be"
+                            f" {int(existing_definitions_in_family[-1]['revision'] + 1)}"
+                        )
+                    )
         else:
             existing = None
 
@@ -930,9 +1094,9 @@ def main():
                                 if list_val not in right_list:
                                     # if list_val is the port mapping, the key 'protocol' may be absent (but defaults to 'tcp')
                                     # fill in that default if absent and see if it is in right_list then
-                                    if isinstance(list_val, dict) and not list_val.get('protocol'):
+                                    if isinstance(list_val, dict) and not list_val.get("protocol"):
                                         modified_list_val = dict(list_val)
-                                        modified_list_val.update(protocol='tcp')
+                                        modified_list_val.update(protocol="tcp")
                                         if modified_list_val in right_list:
                                             continue
                         else:
@@ -942,24 +1106,32 @@ def main():
                 for k, v in right.items():
                     if v and k not in left:
                         # 'essential' defaults to True when not specified
-                        if k == 'essential' and v is True:
+                        if k == "essential" and v is True:
                             pass
                         else:
                             return False
 
                 return True
 
-            def _task_definition_matches(requested_volumes, requested_containers, requested_task_role_arn, requested_launch_type, existing_task_definition):
-                if td['status'] != "ACTIVE":
+            def _task_definition_matches(
+                requested_volumes,
+                requested_containers,
+                requested_task_role_arn,
+                requested_launch_type,
+                existing_task_definition,
+            ):
+                if td["status"] != "ACTIVE":
                     return None
 
-                if requested_task_role_arn != td.get('taskRoleArn', ""):
+                if requested_task_role_arn != td.get("taskRoleArn", ""):
                     return None
 
-                if requested_launch_type is not None and requested_launch_type not in td.get('requiresCompatibilities', []):
+                if requested_launch_type is not None and requested_launch_type not in td.get(
+                    "requiresCompatibilities", []
+                ):
                     return None
 
-                existing_volumes = td.get('volumes', []) or []
+                existing_volumes = td.get("volumes", []) or []
 
                 if len(requested_volumes) != len(existing_volumes):
                     # Nope.
@@ -977,7 +1149,7 @@ def main():
                         if not found:
                             return None
 
-                existing_containers = td.get('containerDefinitions', []) or []
+                existing_containers = td.get("containerDefinitions", []) or []
 
                 if len(requested_containers) != len(existing_containers):
                     # Nope.
@@ -998,42 +1170,51 @@ def main():
 
             # No revision explicitly specified. Attempt to find an active, matching revision that has all the properties requested
             for td in existing_definitions_in_family:
-                requested_volumes = module.params['volumes'] or []
-                requested_containers = module.params['containers'] or []
-                requested_task_role_arn = module.params['task_role_arn']
-                requested_launch_type = module.params['launch_type']
-                existing = _task_definition_matches(requested_volumes, requested_containers, requested_task_role_arn, requested_launch_type, td)
+                requested_volumes = module.params["volumes"] or []
+                requested_containers = module.params["containers"] or []
+                requested_task_role_arn = module.params["task_role_arn"]
+                requested_launch_type = module.params["launch_type"]
+                existing = _task_definition_matches(
+                    requested_volumes, requested_containers, requested_task_role_arn, requested_launch_type, td
+                )
 
                 if existing:
                     break
 
-        if existing and not module.params.get('force_create'):
+        if existing and not module.params.get("force_create"):
             # Awesome. Have an existing one. Nothing to do.
-            results['taskdefinition'] = existing
+            results["taskdefinition"] = existing
         else:
             if not module.check_mode:
                 # Doesn't exist. create it.
-                volumes = module.params.get('volumes', []) or []
-                results['taskdefinition'] = task_mgr.register_task(module.params['family'],
-                                                                   module.params['task_role_arn'],
-                                                                   module.params['execution_role_arn'],
-                                                                   module.params['network_mode'],
-                                                                   module.params['containers'],
-                                                                   volumes,
-                                                                   module.params['launch_type'],
-                                                                   module.params['cpu'],
-                                                                   module.params['memory'],
-                                                                   module.params['placement_constraints'],)
-            results['changed'] = True
+                volumes = module.params.get("volumes", []) or []
+                results["taskdefinition"] = task_mgr.register_task(
+                    module.params["family"],
+                    module.params["task_role_arn"],
+                    module.params["execution_role_arn"],
+                    module.params["network_mode"],
+                    module.params["containers"],
+                    volumes,
+                    module.params["launch_type"],
+                    module.params["cpu"],
+                    module.params["memory"],
+                    module.params["placement_constraints"],
+                    module.params["runtime_platform"],
+                )
+            results["changed"] = True
 
-    elif module.params['state'] == 'absent':
+    elif module.params["state"] == "absent":
         # When de-registering a task definition, we can specify the ARN OR the family and revision.
-        if module.params['state'] == 'absent':
-            if 'arn' in module.params and module.params['arn'] is not None:
-                task_to_describe = module.params['arn']
-            elif 'family' in module.params and module.params['family'] is not None and 'revision' in module.params and \
-                    module.params['revision'] is not None:
-                task_to_describe = module.params['family'] + ":" + str(module.params['revision'])
+        if module.params["state"] == "absent":
+            if "arn" in module.params and module.params["arn"] is not None:
+                task_to_describe = module.params["arn"]
+            elif (
+                "family" in module.params
+                and module.params["family"] is not None
+                and "revision" in module.params
+                and module.params["revision"] is not None
+            ):
+                task_to_describe = module.params["family"] + ":" + str(module.params["revision"])
             else:
                 module.fail_json(msg="To use task definitions, an arn or family and revision must be specified")
 
@@ -1043,16 +1224,16 @@ def main():
             pass
         else:
             # It exists, so we should delete it and mark changed. Return info about the task definition deleted
-            results['taskdefinition'] = existing
-            if 'status' in existing and existing['status'] == "INACTIVE":
-                results['changed'] = False
+            results["taskdefinition"] = existing
+            if "status" in existing and existing["status"] == "INACTIVE":
+                results["changed"] = False
             else:
                 if not module.check_mode:
                     task_mgr.deregister_task(task_to_describe)
-                results['changed'] = True
+                results["changed"] = True
 
     module.exit_json(**results)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
