@@ -148,7 +148,7 @@ seealso:
 - module: community.postgresql.postgresql_ping
 
 notes:
-- State C(dump) and C(restore) don't require I(psycopg2) since version 2.8.
+- State C(dump) and C(restore) don't require I(psycopg) since ansible version 2.8.
 
 attributes:
   check_mode:
@@ -268,26 +268,21 @@ import os
 import subprocess
 import traceback
 
-try:
-    from psycopg2.extras import DictCursor
-except ImportError:
-    HAS_PSYCOPG2 = False
-else:
-    HAS_PSYCOPG2 = True
-
-from ansible_collections.community.postgresql.plugins.module_utils.postgres import (
-    connect_to_db,
-    get_conn_params,
-    ensure_required_libs,
-    postgres_common_argument_spec
-)
 from ansible.module_utils.basic import AnsibleModule
+from ansible.module_utils.six.moves import shlex_quote
+from ansible.module_utils._text import to_native
 from ansible_collections.community.postgresql.plugins.module_utils.database import (
     check_input,
     SQLParseError,
 )
-from ansible.module_utils.six.moves import shlex_quote
-from ansible.module_utils._text import to_native
+from ansible_collections.community.postgresql.plugins.module_utils.postgres import (
+    connect_to_db,
+    ensure_required_libs,
+    get_conn_params,
+    get_server_version,
+    pg_cursor_args,
+    postgres_common_argument_spec
+)
 
 executed_commands = []
 
@@ -342,7 +337,7 @@ def db_exists(cursor, db):
 
 
 def db_dropconns(cursor, db):
-    if cursor.connection.server_version >= 90200:
+    if get_server_version(cursor.connection) >= 90200:
         """ Drop DB connections in Postgres 9.2 and above """
         query_terminate = ("SELECT pg_terminate_backend(pg_stat_activity.pid) FROM pg_stat_activity "
                            "WHERE pg_stat_activity.datname=%(db)s AND pid <> pg_backend_pid()")
@@ -360,7 +355,7 @@ def db_delete(cursor, db, force=False):
     if db_exists(cursor, db):
         query = 'DROP DATABASE "%s"' % db
         if force:
-            if cursor.connection.server_version >= 130000:
+            if get_server_version(cursor.connection) >= 130000:
                 query = ('DROP DATABASE "%s" WITH (FORCE)' % db)
             else:
                 db_dropconns(cursor, db)
@@ -712,7 +707,7 @@ def main():
 
     if not raw_connection:
         db_connection, dummy = connect_to_db(module, conn_params, autocommit=True)
-        cursor = db_connection.cursor(cursor_factory=DictCursor)
+        cursor = db_connection.cursor(**pg_cursor_args)
 
         if session_role:
             try:
