@@ -38,7 +38,7 @@ options:
   policy:
     description:
     - The type of policy to use
-    choices: [ nfs, smb, snapshot, quota ]
+    choices: [ nfs, smb, snapshot, quota, autodir ]
     required: true
     type: str
   enabled:
@@ -60,7 +60,7 @@ options:
     description:
     - Specifies whether the remote client is required to use SMB encryption
     type: bool
-    default: False
+    default: false
   nfs_access:
     description:
     - Specifies access control for the export
@@ -73,10 +73,19 @@ options:
     choices: [ ro, rw ]
     default: rw
     type: str
+  nfs_version:
+    description:
+    - NFS protocol version allowed for the export
+    type: list
+    elements: str
+    choices: [ nfsv3, nfsv4 ]
+    default: nfsv3
+    version_added: "1.22.0"
   user_mapping:
     description:
     - Defines if user mapping is enabled
     type: bool
+    default: true
     version_added: 1.14.0
   snap_at:
     description:
@@ -160,7 +169,7 @@ options:
   anonuid:
     description:
     - The ID to which any users whose UID is affected by I(access) of
-      I(root_squash) or I(all-squash) will be mapped to.
+      I(root-squash) or I(all-squash) will be mapped to.
     - Clear using "".
     type: str
     default: "65534"
@@ -168,7 +177,7 @@ options:
   anongid:
     description:
     - The ID to which any users whose GID is affected by I(access) of
-      I(root_squash) or I(all-squash) will be mapped to.
+      I(root-squash) or I(all-squash) will be mapped to.
     - This is ignored when I(user_mapping) is enabled.
     - Clear using "".
     type: str
@@ -233,8 +242,8 @@ EXAMPLES = r"""
   purestorage.flasharray.purefa_policy:
     name: export1
     policy: smb
-    smb_encrypt: yes
-    smb_anon_allowed: no
+    smb_encrypt: true
+    smb_anon_allowed: false
     client: client1
     fa_url: 10.10.10.2
     api_token: e31060a7-21fc-e277-6240-25983c6c4592
@@ -350,6 +359,8 @@ MIN_QUOTA_API_VERSION = "2.7"
 MIN_SUFFIX_API_VERSION = "2.9"
 USER_MAP_VERSION = "2.15"
 ALL_SQUASH_VERSION = "2.16"
+AUTODIR_VERSION = "2.24"
+NFS_VERSION = "2.26"
 
 
 def _human_to_bytes(size):
@@ -560,7 +571,7 @@ def delete_policy(module, array):
                         if module.params["directory"][old_dir] in dirs:
                             old_dirs.append(module.params["directory"][old_dir])
                 else:
-                    old_dirs = module.params["directory"]
+                    pass
                 if old_dirs:
                     changed = True
                     for rem_dir in range(0, len(old_dirs)):
@@ -607,7 +618,51 @@ def delete_policy(module, array):
                                     deleted.errors[0].message,
                                 )
                             )
-        else:
+        elif module.params["policy"] == "autodir":
+            if not module.params["directory"]:
+                res = array.delete_policies_autodir(names=[module.params["name"]])
+                if res.status_code == 200:
+                    changed = True
+                else:
+                    module.fail_json(
+                        msg="Deletion of Autodir policy {0} failed. Error: {1}".format(
+                            module.params["name"], res.errors[0].message
+                        )
+                    )
+            if module.params["directory"]:
+                dirs = []
+                old_dirs = []
+                current_dirs = list(
+                    array.get_directories_policies_autodir(
+                        policy_names=[module.params["name"]]
+                    ).items
+                )
+                if current_dirs:
+                    for current_dir in range(0, len(current_dirs)):
+                        dirs.append(current_dirs[current_dir].member.name)
+                    for old_dir in range(0, len(module.params["directory"])):
+                        if module.params["directory"][old_dir] in dirs:
+                            old_dirs.append(module.params["directory"][old_dir])
+                else:
+                    pass
+                if old_dirs:
+                    changed = True
+                    for rem_dir in range(0, len(old_dirs)):
+                        if not module.check_mode:
+                            directory_removed = (
+                                array.delete_directories_policies_autodir(
+                                    member_names=[old_dirs[rem_dir]],
+                                    policy_names=module.params["name"],
+                                )
+                            )
+                            if directory_removed.status_code != 200:
+                                module.fail_json(
+                                    msg="Failed to remove directory from Autodir policy {0}. Error: {1}".format(
+                                        module.params["name"],
+                                        directory_removed.errors[0].message,
+                                    )
+                                )
+        else:  # quota
             if module.params["quota_limit"]:
                 quota_limit = _human_to_bytes(module.params["quota_limit"])
                 rules = list(
@@ -704,9 +759,15 @@ def create_policy(module, array, all_squash):
             )
 
             if created.status_code == 200:
-                policy = flasharray.PolicyNfsPost(
-                    user_mapping_enabled=module.params["user_mapping"],
-                )
+                if version.parse(NFS_VERSION) > version.parse(array.get_rest_version()):
+                    policy = flasharray.PolicyNfsPost(
+                        user_mapping_enabled=module.params["user_mapping"],
+                    )
+                else:
+                    policy = flasharray.PolicyNfsPost(
+                        user_mapping_enabled=module.params["user_mapping"],
+                        nfs_version=module.params["nfs_version"],
+                    )
                 res = array.patch_policies_nfs(
                     names=[module.params["name"]], policy=policy
                 )
@@ -863,7 +924,38 @@ def create_policy(module, array, all_squash):
                         module.params["name"], created.errors[0].message
                     )
                 )
-        else:
+        elif module.params["policy"] == "autodir":
+            created = array.post_policies_autodir(
+                names=[module.params["name"]],
+                policy=flasharray.PolicyPost(enabled=module.params["enabled"]),
+            )
+            if created.status_code == 200:
+                changed = True
+                if module.params["directory"]:
+                    policies = flasharray.DirectoryPolicyPost(
+                        policies=[
+                            flasharray.DirectorypolicypostPolicies(
+                                policy=flasharray.Reference(name=module.params["name"])
+                            )
+                        ]
+                    )
+                    directory_added = array.post_directories_policies_autodir(
+                        member_names=module.params["directory"], policies=policies
+                    )
+                    if directory_added.status_code != 200:
+                        module.fail_json(
+                            msg="Failed to add directory for Autodir policy {0}. Error: {1}".format(
+                                module.params["name"],
+                                directory_added.errors[0].message,
+                            )
+                        )
+            else:
+                module.fail_json(
+                    msg="Failed to create Autodir policy {0}. Error: {1}".format(
+                        module.params["name"], created.errors[0].message
+                    )
+                )
+        else:  # quota
             created = array.post_policies_quota(
                 names=[module.params["name"]],
                 policy=flasharray.PolicyPost(enabled=module.params["enabled"]),
@@ -988,20 +1080,40 @@ def update_policy(module, array, api_version, all_squash):
                         rule_name = rules[rule].name
                         break
                 if not rule_name:
-                    if all_squash:
-                        rules = flasharray.PolicyrulenfsclientpostRules(
-                            permission=module.params["nfs_permission"],
-                            client=module.params["client"],
-                            anongid=module.params["anongid"],
-                            anonuid=module.params["anonuid"],
-                            access=module.params["nfs_access"],
-                        )
+                    if version.parse(NFS_VERSION) > version.parse(
+                        array.get_rest_version()
+                    ):
+                        if all_squash:
+                            rules = flasharray.PolicyrulenfsclientpostRules(
+                                permission=module.params["nfs_permission"],
+                                client=module.params["client"],
+                                anongid=module.params["anongid"],
+                                anonuid=module.params["anonuid"],
+                                access=module.params["nfs_access"],
+                            )
+                        else:
+                            rules = flasharray.PolicyrulenfsclientpostRules(
+                                permission=module.params["nfs_permission"],
+                                client=module.params["client"],
+                                access=module.params["nfs_access"],
+                                nfs_version=module.params["nfs_version"],
+                            )
                     else:
-                        rules = flasharray.PolicyrulenfsclientpostRules(
-                            permission=module.params["nfs_permission"],
-                            client=module.params["client"],
-                            access=module.params["nfs_access"],
-                        )
+                        if all_squash:
+                            rules = flasharray.PolicyrulenfsclientpostRules(
+                                permission=module.params["nfs_permission"],
+                                client=module.params["client"],
+                                anongid=module.params["anongid"],
+                                anonuid=module.params["anonuid"],
+                                access=module.params["nfs_access"],
+                                nfs_version=module.params["nfs_version"],
+                            )
+                        else:
+                            rules = flasharray.PolicyrulenfsclientpostRules(
+                                permission=module.params["nfs_permission"],
+                                client=module.params["client"],
+                                access=module.params["nfs_access"],
+                            )
                     rule = flasharray.PolicyRuleNfsClientPost(rules=[rules])
                     changed_rule = True
                     if not module.check_mode:
@@ -1317,7 +1429,69 @@ def update_policy(module, array, api_version, all_squash):
                                 rule_created.errors[err_no].message,
                             )
                         )
-    else:
+    elif module.params["policy"] == "autodir":
+        try:
+            current_enabled = list(
+                array.get_policies_autodir(names=[module.params["name"]]).items
+            )[0].enabled
+        except Exception:
+            module.fail_json(
+                msg="Incorrect policy type specified for existing policy {0}".format(
+                    module.params["name"]
+                )
+            )
+        if current_enabled != module.params["enabled"]:
+            changed_enable = True
+            if not module.check_mode:
+                res = array.patch_policies_autodir(
+                    names=[module.params["name"]],
+                    policy=flasharray.PolicyPatch(enabled=module.params["enabled"]),
+                )
+                if res.status_code != 200:
+                    module.exit_json(
+                        msg="Failed to enable/disable autodir policy {0}".format(
+                            module.params["name"]
+                        )
+                    )
+        if module.params["directory"]:
+            dirs = []
+            new_dirs = []
+            current_dirs = list(
+                array.get_directories_policies_autodir(
+                    policy_names=[module.params["name"]]
+                ).items
+            )
+            if current_dirs:
+                for current_dir in range(0, len(current_dirs)):
+                    dirs.append(current_dirs[current_dir].member.name)
+                for new_dir in range(0, len(module.params["directory"])):
+                    if module.params["directory"][new_dir] not in dirs:
+                        changed_dir = True
+                        new_dirs.append(module.params["directory"][new_dir])
+            else:
+                new_dirs = module.params["directory"]
+            if new_dirs:
+                policies = flasharray.DirectoryPolicyPost(
+                    policies=[
+                        flasharray.DirectorypolicypostPolicies(
+                            policy=flasharray.Reference(name=module.params["name"])
+                        )
+                    ]
+                )
+                changed_dir = True
+                for add_dir in range(0, len(new_dirs)):
+                    if not module.check_mode:
+                        directory_added = array.post_directories_policies_autodir(
+                            member_names=[new_dirs[add_dir]], policies=policies
+                        )
+                        if directory_added.status_code != 200:
+                            module.fail_json(
+                                msg="Failed to add new directory to Autodir policy {0}. Error: {1}".format(
+                                    module.params["name"],
+                                    directory_added.errors[0].message,
+                                )
+                            )
+    else:  # quota
         current_enabled = list(
             array.get_policies_quota(names=[module.params["name"]]).items
         )[0].enabled
@@ -1519,7 +1693,9 @@ def main():
             ),
             nfs_permission=dict(type="str", default="rw", choices=["rw", "ro"]),
             policy=dict(
-                type="str", required=True, choices=["nfs", "smb", "snapshot", "quota"]
+                type="str",
+                required=True,
+                choices=["nfs", "smb", "snapshot", "quota", "autodir"],
             ),
             name=dict(type="str", required=True),
             rename=dict(type="str"),
@@ -1540,8 +1716,14 @@ def main():
             quota_notifications=dict(
                 type="list", elements="str", choices=["user", "group"]
             ),
-            user_mapping=dict(type="bool"),
+            user_mapping=dict(type="bool", default=True),
             directory=dict(type="list", elements="str"),
+            nfs_version=dict(
+                type="list",
+                elements="str",
+                choices=["nfsv3", "nfsv4"],
+                default=["nfsv3"],
+            ),
         )
     )
 
@@ -1565,6 +1747,11 @@ def main():
             msg="FlashArray REST version not supportedi for directory quotas. "
             "Minimum version required: {0}".format(MIN_QUOTA_API_VERSION)
         )
+    if module.params["policy"] == "autodir" and AUTODIR_VERSION not in api_version:
+        module.fail_json(
+            msg="FlashArray REST version not supported for autodir policies. "
+            "Minimum version required: {0}".format(AUTODIR_VERSION)
+        )
     array = get_array(module)
     state = module.params["state"]
     if module.params["quota_notifications"]:
@@ -1580,21 +1767,22 @@ def main():
         module.params["quota_notifications"] = []
 
     if (
-        module.params["nfs_access"] == "all_squash"
+        module.params["nfs_access"] == "all-squash"
         and ALL_SQUASH_VERSION not in api_version
     ):
         module.fail_json(
-            msg="all_squash is not supported in this version of Purity//FA"
+            msg="all-squash is not supported in this version of Purity//FA"
         )
 
+    all_squash = ALL_SQUASH_VERSION in api_version
     exists = bool(array.get_policies(names=[module.params["name"]]).status_code == 200)
 
     if state == "present" and not exists:
-        create_policy(module, array)
+        create_policy(module, array, all_squash)
     elif state == "present" and exists and module.params["rename"]:
         rename_policy(module, array)
     elif state == "present" and exists:
-        update_policy(module, array, api_version)
+        update_policy(module, array, api_version, all_squash)
     elif state == "absent" and exists:
         delete_policy(module, array)
 
